'''
COPYRIGHT
Example Data Cleaning Syntax to prepare ED data for deterministic linkage
Copyright (C) 2022  Charlotte Baker

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

Email Contact: bakerc@vt.edu or charlotte.m.h.baker@gmail.com
'''







'''Hospital Inpatient

Note. If your data has a complex data structure (weights, clusters, strata, etc),
instead of restricting the data (we do this 3 times)
you'll need to create domain variables instead.

For example, instead of the statement

ed06x1 = ed06x[ed06x["PTSTATE"]=='FL']

you will need to make a new variable to use in later analyses:
  
def domain(x):
  if x=='FL':
    return 1
  else:
    return 0

ed06x2['DOMAIN']=ed06x2['PTSTATE'].apply(domain)

'''

import pandas as pd
import numpy as np


'''reduce number of variables (columns) in data'''
h06 = pd.read_sas('E:/In Progress Projects/injury epi - florida/Analysis/Hospital/hosp06.sas7bdat',format='sas7bdat', encoding='iso-8859-1') #important to add the encoding part
h06.to_pickle('~/documents/practicepythoninstudio/h06.pkl') # save.
h06 = pd.read_pickle('~/documents/practicepythoninstudio/h06.pkl') # load.

colsToScale=["MASKSSN", "YEAR", "QTR", "GENDER", "SEX", "ETHNICITY", "RACE", "AGE", "DISCHSTAT", "LOSDAYS", "ADMTYPE", "ADMSRC","HR_ARRIVAL", "PAYER", "PTSTATE", "ADMITDIAG",  "PRINDIAG", "OTHDIAG", "POA", "ECODE", "PRINPROC", "OTHPROC",  "WEEKDAY", "DAYS",    
"ERCHGS", "TRAUMACHGS", "PHYOCCHGS","TCHGS" ]
h06x = h06[h06.columns[h06.columns.str.startswith(tuple(colsToScale))]] 

'''select observations (index) for state residents only'''
h06x1 = h06x[h06x["PTSTATE"]=='FL']

h06x2 = h06x1.copy()

'''systematically making variables the same name, same length, same type (numbers or words)'''

'''sex var is originally called gender and is character but needs to be numeric (looks like a number but originally was actually encoded as text) and we want to call it sex

this syntax makes a new SEX variable called sex_grp_if which only contains values of 1 or 2 (any other values are turned to missing. we'll drop  gender later.
'''

def sex_grp_if(x):
  if x=='1':
    return 1
  elif x=='2':
    return 2
  
h06x2['sex_grp_if']=h06x2['GENDER'].apply(sex_grp_if)


'''race var is originally character but needs to be numeric (looks like a number but originally was actually encoded as text).

this syntax makes a new RACE variable called race_grp_if which only contains values of 1 through 7 (any other values are turned to missing.
'''

h06x2['race_grp'] = np.select([(h06x2['RACE']=='1'),
                                     (h06x2['RACE']=='2'),
                                     (h06x2['RACE']=='3'),
                                     (h06x2['RACE']=='4'),
                                     (h06x2['RACE']=='5'),
                                     (h06x2['RACE']=='6'),
                                     (h06x2['RACE']=='7')],
                                    [1,
                                     2,
                                     3,
                                     4,
                                     5,
                                     6,
                                     7]) 


'''hour of arrival var is originally character but needs to be numeric (looks like a number but originally was actually encoded as text)

this syntax makes a new HR_ARRIVAL variable called HRA_if which only contains values of 1 to 23 (any other values are turned to missing.
'''

h06x2['HRA_if'] = np.select([(h06x2['HR_ARRIVAL']=='01'),
                                     (h06x2['HR_ARRIVAL']=='02'),
                                     (h06x2['HR_ARRIVAL']=='03'),
                                     (h06x2['HR_ARRIVAL']=='04'),
                                     (h06x2['HR_ARRIVAL']=='05'),
                                     (h06x2['HR_ARRIVAL']=='06'),
                                     (h06x2['HR_ARRIVAL']=='07'),
                                     (h06x2['HR_ARRIVAL']=='08'),
                                     (h06x2['HR_ARRIVAL']=='09'),
                                     (h06x2['HR_ARRIVAL']=='10'),
                                     (h06x2['HR_ARRIVAL']=='11'),
                                     (h06x2['HR_ARRIVAL']=='12'),
                                     (h06x2['HR_ARRIVAL']=='13'),
                                     (h06x2['HR_ARRIVAL']=='14'),
                                     (h06x2['HR_ARRIVAL']=='15'),
                                     (h06x2['HR_ARRIVAL']=='16'),
                                     (h06x2['HR_ARRIVAL']=='17'),
                                     (h06x2['HR_ARRIVAL']=='18'),
                                     (h06x2['HR_ARRIVAL']=='19'),
                                     (h06x2['HR_ARRIVAL']=='20'),
                                     (h06x2['HR_ARRIVAL']=='21'),
                                     (h06x2['HR_ARRIVAL']=='22'),
                                     (h06x2['HR_ARRIVAL']=='23')],
                                    [1,
                                     2,
                                     3,
                                     4,
                                     5,
                                     6,
                                     7,
                                     8,
                                     9,
                                     10,
                                     11,
                                     12,
                                     13,
                                     14,
                                     15,
                                     16,
                                     17,
                                     18,
                                     19,
                                     20,
                                     21,
                                     22,
                                     23]) 


'''Drop original hr_arrival race gender because not needed anymore'''

h06x3=h06x2.drop(['HR_ARRIVAL', 'RACE', 'GENDER'], axis=1)

'''Rename the new variables with the old names for consistency'''
h06x4 = h06x3.rename(columns = {"race_grp" : "RACE", "sex_grp_if" : "SEX", "HRA_if" : "HR_ARRIVAL"})

 
h06x5 = h06x4.copy()

'''
need to find and keep records for those with icd codes of interest. first, make the variable for identifying SRI.
'''

def sport(x):
  choice = ['E001' , 'E002' , 'E003' ,  'E004' , 'E005' , 'E006' , 'E007' , 'E008' , 'E009' ,  'E010']
  chance = ['E849.4' , 'E885.0'  , 'E885.1' , 'E885.2'  , 'E885.3'  , 'E885.4' , 'E886.0'  , 'E910.0'  , 'E910.1' , 'E910.2'  , 'E917.0'  , 'E917.5']
  if x.startswith(tuple(choice)):
    return 1
  elif x in chance:
    return 1
  else:
    return 0
 
'''Our ECODE variables were float format so we made sure to convert to string'''
h06x5[['aECODE1', 'bECODE2', 'cECODE3']]=h06x5[['ECODE1', 'ECODE2', 'ECODE3']].astype(str)

'''Create the SRI variable is a two step process.'''
h06x5['SRa']=h06x5['aECODE1'].apply(sport)
h06x5['SRb']=h06x5['bECODE2'].apply(sport)
h06x5['SRc']=h06x5['cECODE3'].apply(sport) 

for idx in h06x5.index:
  if h06x5.at[idx, 'SRa'] == 1 or h06x5.at[idx, 'SRb'] == 1 or h06x5.at[idx, 'SRc'] == 1:
        h06x5.at[idx, 'SRI'] = 1
  else:
        h06x5.at[idx, 'SRI'] = 0

'''Now that we're finished, we can drop SRa, SRb, SRc and aECODE1, bECODE2, cECODE3 variables because they are not needed'''
h06x6=h06x5.drop(['SRa', 'SRb', 'SRc', 'aECODE1', 'bECODE2', 'cECODE3'], axis=1)


'''the value of 1 indicates that the record has greater than or equal to one e-codes for SRI



Process to run an altered ICD-9-CM external cause of injury code matrix


need to find and keep records for those with icd codes of
interest. second, identify unintentional injuries and retain 
just those in the data.

ALTERATION of code from NCIPC (CDC)
http://www.cdc.gov/nchs/injury/injury_tools.htm

The original syntax asks that you make 3 variables to identify
cause and mechanism of injuries. In this case, we did not
particularly need the mechanism, just the cause.

Original:
 
ICD-9-CM external-cause-of-injury code Matrix
Variable names used in the SAS statements 
CAUSEDET: 3 DIGIT ICD CODE fields for morbidity data
CAUSEDT4: 4 DIGIT ICD CODE field for morbidity data
PERSINJ:  4TH DIGIT OF THE ICD CODE


Ones used in this project:
CAUSEDET: 3 DIGIT ICD CODE fields for morbidity data

This variable needs to be made for every e-code variable that
exists in the data so you see causedet causedet2 causedet3


remove the periods from the e-codes (e.g. E849.4 becomes E8494 then remove the letter from the front of ecodes, then keep the first three numbers that remain (e.g. E8494 becomes 849)
finally convert the values to numeric
'''

h06x7 = h06x6.copy()

h06x7['E1x'] = h06x7['ECODE1'].str.replace('.','').str[1:4]
h06x7['causedet']=pd.to_numeric(h06x7['E1x'],downcast="integer", errors='coerce')

h06x7['E2x'] = h06x7['ECODE2'].str.replace('.','').str[1:4]
h06x7['causedet2']=pd.to_numeric(h06x7['E2x'],downcast="integer", errors='coerce')

h06x7['E3x'] = h06x7['ECODE3'].str.replace('.','').str[1:4]
h06x7['causedet3']=pd.to_numeric(h06x7['E3x'],downcast="integer", errors='coerce')

'''identify unintentional injuries using the external cause matrix

this process creates a variable called unintentional'''

def efix(x):
  if ((x>=800 and x<=869) or (x>=880 and x<=929)):
    return 1;
  else:
    return 0
  
h06x7['inj1']=h06x7['causedet'].apply(efix)
h06x7['inj2']=h06x7['causedet2'].apply(efix)
h06x7['inj3']=h06x7['causedet3'].apply(efix)

for ij in h06x7.index:
  if h06x7.at[ij, 'inj1'] == 1 or h06x7.at[ij, 'inj2'] == 1 or h06x7.at[ij, 'inj3'] == 1:
    h06x7.at[ij, 'unintentional'] = 1
  else:
    h06x7.at[ij, 'unintentional'] = 0

'''
unintentional = 1 if the observation has an unintentional injury present
unintentional = 0 if the observatino does not have an unintentional injury present


can drop inj1, inj2, inj3 and E1x, E2x, E3x variables'''


h06x8=h06x7.drop(['inj1', 'inj2', 'inj3', 'E1x', 'E2x', 'E3x'], axis=1)

'''End of matrix code'''


'''Update columns before moving on. Can do this now or later when making new columns but needs to be done'''
colsToScale3=["MASKSSN", "YEAR", "QTR", "SEX", "RACE", "AGE", "DISCHSTAT", "LOSDAYS", "ADMTYPE", "ADMSRC","HR_ARRIVAL", "PAYER", "PTSTATE", "ADMITDIAG",  "PRINDIAG", "OTHDIAG", "POA", "ECODE", "PRINPROC", "OTHPROC",  "WEEKDAY", "DAYS",    
"ERCHGS", "TRAUMACHGS", "PHYOCCHGS","TCHGS",
"unintentional", "SRI", "causedet"]

h06x9 = h06x8.copy()
h06x9 = h06x9[h06x9.columns[h06x9.columns.str.startswith(tuple(colsToScale3))]]


'''make sure these variables appropriately do not have decimals'''

h06x9['YEAR']=pd.to_numeric(h06x9['YEAR'], downcast="integer", errors='coerce')
h06x9['QTR']=pd.to_numeric(h06x9['QTR'], downcast="integer", errors='coerce')
h06x9['AGE']=pd.to_numeric(h06x9['AGE'], downcast="integer", errors='coerce')
h06x9['LOSDAYS']=pd.to_numeric(h06x9['LOSDAYS'], downcast="integer", errors='coerce')
h06x9['SRI']=pd.to_numeric(h06x9['SRI'], downcast="integer", errors='coerce')
h06x9['unintentional']=pd.to_numeric(h06x9['unintentional'], downcast="integer", errors='coerce')

h06x9.to_pickle('~/documents/practicepythoninstudio/h06-entire.pkl') # save.

'''next steps are to restrict data using the unintentional and SRI variables

drop observations that do not have an unintentional injury'''

h06x10 = h06x9.copy()
h06x10 = h06x10.loc[h06x8["unintentional"]==1]

h06x10.to_pickle('~/documents/practicepythoninstudio/h06-unint.pkl') # save.

'''drop observations that do not have an SRI'''
h06x11 = h06x10.copy()
h06x11 = h06x11.loc[h06x11["SRI"]==1]


h06x11.to_pickle('~/documents/practicepythoninstudio/h06-sri.pkl') # save.





'''
End of syntax for 2006-2009.
Copy, paste, change data set names, and repeat for every year
in that range. Result should be 4 data sets (2006, 2007, 2008,
2009) containing records for those with unintentional SRI
'''



#2010-2012

h12 = pd.read_sas('E:/In Progress Projects/injury epi - florida/Analysis/Hospital/hosp12.sas7bdat',format='sas7bdat', encoding='iso-8859-1') #important to add the encoding part
h12.to_pickle('~/documents/practicepythoninstudio/h12.pkl') # save.
h12 = pd.read_pickle('~/documents/practicepythoninstudio/h12.pkl') # load.

colsToScale=["MASKSSN", "YEAR", "QTR", "GENDER", "SEX", "ETHNICITY", "RACE", "AGE", "DISCHSTAT", "LOSDAYS", "ADM_PRIOR", "ADMTYPE", "ADMSRC","HR_ARRIVAL", "EDHR_ARR",  "PAYER", "PTSTATE", "ADMITDIAG",  "PRINDIAG", "OTHDIAG", "POA", "ECODE", "PRINPROC", "OTHPROC",  "WEEKDAY", "DAYS",    
"ERCHGS", "TRAUMACHGS", "PHYOCCHGS","TCHGS", "OCCUPCHGS", "SPEECHGS", "PHYTHCHGS" ]


'''reduce number of variables (columns) in data'''
h12x = h12[h12.columns[h12.columns.str.startswith(tuple(colsToScale))]] 

'''select observations for state residents only'''
h12x1 = h12x[h12x["PTSTATE"]=='FL']

h12x2 = h12x1.copy()

'''systematically making variables the same name, same length, same type (numbers or words)




data in other years is numeric (1,2) so make the data match for SEX'''
def sex_grp_if(x):
  if x=='M':
    return 1;
  elif x=='F':
    return 2
  
h12x2['sex_grp_if']=h12x2['SEX'].apply(sex_grp_if)


'''race var is originally character but needs to be numeric (looks like a number but originally was actually encoded as text)

recode race and ethnicity variables to create a new variable for race that matches what the race variable looked like in previous years'''


h12x2['race_grp'] = np.select([(h12x2['RACE']=='1'),
                                     ((h12x2['RACE']=='2') | (h12x2['RACE']=='4')),
                                     ((h12x2['RACE']=='3') & ((h12x2['ETHNICITY']=='E2') | (h12x2['ETHNICITY']=='E7'))),
                                     ((h12x2['RACE']=='5') & ((h12x2['ETHNICITY']=='E2') | (h12x2['ETHNICITY']=='E7'))),
                                     ((h12x2['RACE']=='5') & ((h12x2['ETHNICITY']=='E1'))),
                                     ((h12x2['RACE']=='3') & ((h12x2['ETHNICITY']=='E1'))),
                                     ((h12x2['RACE']=='7') | (h12x2['RACE']==''))],
                                    [1,
                                     2,
                                     3,
                                     4,
                                     5,
                                     6,
                                     8]) 
 def race_grp_if(x):
  if (x==1):
    return 1
  elif (x==2):
    return 2
  elif (x==3):
    return 3
  elif (x==4):
    return 4
  elif (x==5):
    return 5
  elif (x==6):
    return 6
  elif (x==8):
    return 8
  else:
    return 7


h12x2['race_grp_if']=h12x2['race_grp'].apply(race_grp_if)
  
h12x2['race_grp2']=h12x2['race_grp_if'].replace(8, np.NaN)





                                     
'''hour of arrival var is originally character but needs to be numeric (looks like a number but originally was actually encoded as text)'''

h12x2['HR_ARRIVAL'] = np.select([(h12x2['EDHR_ARR']=='01'),
                                     (h12x2['EDHR_ARR']=='02'),
                                     (h12x2['EDHR_ARR']=='03'),
                                     (h12x2['EDHR_ARR']=='04'),
                                     (h12x2['EDHR_ARR']=='05'),
                                     (h12x2['EDHR_ARR']=='06'),
                                     (h12x2['EDHR_ARR']=='07'),
                                     (h12x2['EDHR_ARR']=='08'),
                                     (h12x2['EDHR_ARR']=='09'),
                                     (h12x2['EDHR_ARR']=='10'),
                                     (h12x2['EDHR_ARR']=='11'),
                                     (h12x2['EDHR_ARR']=='12'),
                                     (h12x2['EDHR_ARR']=='13'),
                                     (h12x2['EDHR_ARR']=='14'),
                                     (h12x2['EDHR_ARR']=='15'),
                                     (h12x2['EDHR_ARR']=='16'),
                                     (h12x2['EDHR_ARR']=='17'),
                                     (h12x2['EDHR_ARR']=='18'),
                                     (h12x2['EDHR_ARR']=='19'),
                                     (h12x2['EDHR_ARR']=='20'),
                                     (h12x2['EDHR_ARR']=='21'),
                                     (h12x2['EDHR_ARR']=='22'),
                                     (h12x2['EDHR_ARR']=='23')],
                                    [1,
                                     2,
                                     3,
                                     4,
                                     5,
                                     6,
                                     7,
                                     8,
                                     9,
                                     10,
                                     11,
                                     12,
                                     13,
                                     14,
                                     15,
                                     16,
                                     17,
                                     18,
                                     19,
                                     20,
                                     21,
                                     22,
                                     23]) 




'''drop original variables (RACE, ETHNICITY, EDHR_ARR, SEX) because unneeded'''

h12x3=h12x2.drop(['EDHR_ARR', 'RACE', 'ETHNICITY', 'SEX'], axis=1)

'''rename new variables with the old names for consistency. also rename adm_prior admtype to be consistent'''
h12x4 = h12x3.rename(columns = {"race_grp2" : "RACE", "sex_grp_if" : "SEX", "ADM_PRIOR" : "ADMTYPE"})

'''calculate phyocchgs from phythchgs, occupchgs and speechgs then drop the originals'''

h12x4['PHYOCCHGS'] = h12x4['PHYTHCHGS'] + h12x4['OCCUPCHGS'] + h12x4['SPEECHGS']


h12x5=h12x4.drop(['PHYTHCHGS', 'OCCUPCHGS', 'SPEECHGS'], axis=1)




'''need to find and keep records for those with icd codes of interest. first, make the variable for identifying SRI

the value of 1 indicates that the record has 
greater than or equal to one e-codes for SRI'''

def sport(x):
  choice = ['E001' , 'E002' , 'E003' ,  'E004' , 'E005' , 'E006' , 'E007' , 'E008' , 'E009' ,  'E010']
  chance = ['E849.4' , 'E885.0'  , 'E885.1' , 'E885.2'  , 'E885.3'  , 'E885.4' , 'E886.0'  , 'E910.0'  , 'E910.1' , 'E910.2'  , 'E917.0'  , 'E917.5']
  if x.startswith(tuple(choice)):
    return 1
  elif x in chance:
    return 1
  else:
    return 0
 
h12x5[['aECODE1', 'bECODE2', 'cECODE3']]=h12x5[['ECODE1', 'ECODE2', 'ECODE3']].astype(str)
h12x5['SRa']=h12x5['aECODE1'].apply(sport)
h12x5['SRb']=h12x5['bECODE2'].apply(sport)
h12x5['SRc']=h12x5['cECODE3'].apply(sport) 

for idx in h12x5.index:
  if h12x5.at[idx, 'SRa'] == 1 or h12x5.at[idx, 'SRb'] == 1 or h12x5.at[idx, 'SRc'] == 1:
        h12x5.at[idx, 'SRI'] = 1
  else:
        h12x5.at[idx, 'SRI'] = 0

'''can drop SRa, SRb, SRc variables'''

h12x5=h12x5.drop(['SRa', 'SRb', 'SRc'], axis=1)




'''Process to run an altered ICD-9-CM external cause of injury code matrix


need to find and keep records for those with icd codes of
interest. second, identify unintentional injuries and retain 
just those in the data.

ALTERATION of code from NCIPC (CDC)
http://www.cdc.gov/nchs/injury/injury_tools.htm

The original syntax asks that you make 3 variables to identify
cause and mechanism of injuries. In this case, we did not
particularly need the mechanism, just the cause.

Original:
 
ICD-9-CM external-cause-of-injury code Matrix
Variable names used in the SAS statements 
CAUSEDET: 3 DIGIT ICD CODE fields for morbidity data
CAUSEDT4: 4 DIGIT ICD CODE field for morbidity data
PERSINJ:  4TH DIGIT OF THE ICD CODE


Ones used in this project:
CAUSEDET: 3 DIGIT ICD CODE fields for morbidity data

This variable needs to be made for every e-code variable that
exists in the data so you see causedet causedet2 causedet3


remove the periods from the e-codes (e.g. E849.4 becomes E8494 then remove the letter from the front of ecodes, then keep the first three numbers that remain (e.g. E8494 becomes 849)
finally convert the values to numeric

'''

h12x6 = h12x5.copy()

h12x6['E1x'] = h12x6['ECODE1'].str.replace('.','').str[1:4]
h12x6['causedet']=pd.to_numeric(h12x6['E1x'],downcast="integer", errors='coerce')

h12x6['E2x'] = h12x6['ECODE2'].str.replace('.','').str[1:4]
h12x6['causedet2']=pd.to_numeric(h12x6['E2x'],downcast="integer", errors='coerce')

h12x6['E3x'] = h12x6['ECODE3'].str.replace('.','').str[1:4]
h12x6['causedet3']=pd.to_numeric(h12x6['E3x'],downcast="integer", errors='coerce')




'''identify unintentional injuries using the external cause matrix

this process creates a variable called unintentional'''


def efix(x):
  if ((x>=800 and x<=869) or (x>=880 and x<=929)):
    return 1
  else:
    return 0
  
h12x6['inj1']=h12x6['causedet'].apply(efix)
h12x6['inj2']=h12x6['causedet2'].apply(efix)
h12x6['inj3']=h12x6['causedet3'].apply(efix)


for ij in h12x6.index:
  if h12x6.at[ij, 'inj1'] == 1 or h12x6.at[ij, 'inj2'] == 1 or h12x6.at[ij, 'inj3'] == 1:
    h12x6.at[ij, 'unintentional'] = 1
  else:
    h12x6.at[ij, 'unintentional'] = 0
    


'''unintentional = 1 if the observation has an unintentional injury present
unintentional = 0 if the observatino does not have an unintentional injury present


can drop inj1, inj2, inj3 and E1x, E2x, E3x variables'''

h12x7=h12x6.drop(['inj1', 'inj2', 'inj3', 'E1x', 'E2x', 'E3x'], axis=1)

'''end of matrix code'''


#Update columns before moving on. Can do this now or later when making new columns but needs to be done

colsToScale3=["MASKSSN", "YEAR", "QTR", "GENDER", "SEX", "ETHNICITY", "RACE", "AGE", "DISCHSTAT", "LOSDAYS", "ADMTYPE", "ADMSRC","HR_ARRIVAL", "EDHR_ARR",  "PAYER", "PTSTATE", "ADMITDIAG",  "PRINDIAG", "OTHDIAG", "POA", "ECODE", "PRINPROC", "OTHPROC",  "WEEKDAY", "DAYS",    
"ERCHGS", "TRAUMACHGS", "PHYOCCHGS","TCHGS", "OCCUPCHGS", "SPEECHGS", "PHYTHCHGS",
"unintentional", "SRI", "causedet"]

h12x8 = h12x7.copy()
h12x8 = h12x8[h12x8.columns[h12x8.columns.str.startswith(tuple(colsToScale3))]]

'''make sure these variables appropriately do not have decimals'''

h12x8['YEAR']=pd.to_numeric(h12x8['YEAR'], downcast="integer", errors='coerce')
h12x8['QTR']=pd.to_numeric(h12x8['QTR'], downcast="integer", errors='coerce')
h12x8['AGE']=pd.to_numeric(h12x8['AGE'], downcast="integer", errors='coerce')
h12x8['LOSDAYS']=pd.to_numeric(h12x8['LOSDAYS'], downcast="integer", errors='coerce')
h12x8['SRI']=pd.to_numeric(h12x8['SRI'], downcast="integer", errors='coerce')
h12x8['unintentional']=pd.to_numeric(h12x8['unintentional'], downcast="integer", errors='coerce')


h12x8.to_pickle('~/documents/practicepythoninstudio/h12-entire.pkl') # save.

'''next steps are to restrict data using the unintentional and SRI variables

drop observations that do not have an unintentional injury'''
h12x9 = h12x8.copy()
h12x9 = h12x9.loc[h12x9["unintentional"]==1]

h12x9.to_pickle('~/documents/practicepythoninstudio/h12-unint.pkl') # save.

'''drop observations that do not have an SRI'''

h12x10 = h12x9.copy()
h12x10 = h12x10.loc[h12x10["SRI"]==1]


h12x10.to_pickle('~/documents/practicepythoninstudio/h12-sri.pkl') # save.

'''
End of syntax for 2010-2012.
Copy, paste, change data set names, and repeat for every year in that range. Result should be 3 data sets (2010, 2011, 2012) containing records for those with unintentional SRI
'''

'''If you want all the data not just unintentional SRI -
Concatenation'''
hmergea=pd.concat([h06x9, h12x8])

hmergea.to_pickle('~/documents/practicepythoninstudio/hmerge-entire.pkl') # save.

'''If you want all unintentional injuries not just records
with SRI - Concatenation'''
hmergeu=pd.concat([h06x10, h12x9])

hmergeu.to_pickle('~/documents/practicepythoninstudio/hmerge-unint.pkl') # save.

'''If you want unintentional SRI records only - Concatenation'''
hmerges=pd.concat([h06x11, h12x10])

hmerges.to_pickle('~/documents/practicepythoninstudio/hmerge-sri.pkl') # save.
